// Copyright (c) 2024 Proton AG
//
// This file is part of Proton Mail Bridge.
//
// Proton Mail Bridge is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Proton Mail Bridge is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Proton Mail Bridge. If not, see <https://www.gnu.org/licenses/>.


#include "BridgeApp.h"
#include <bridgepp/Exception/Exception.h>


using namespace bridgepp;


//****************************************************************************************************************************************************
/// \param[in] argc The number of command-line arguments.
/// \param[in] argv The list of command-line arguments.
//****************************************************************************************************************************************************
BridgeApp::BridgeApp(int &argc, char **argv)
    : QApplication(argc, argv) {

}


//****************************************************************************************************************************************************
/// \param[in] object The object.
/// \param[in] event The event.
//****************************************************************************************************************************************************
bool BridgeApp::notify(QObject *object, QEvent *event) {
    try {
        return QApplication::notify(object, event);
    } catch (Exception const &e) {
        emit fatalError(__func__, e.qwhat());
    } catch (...) {
        emit fatalError(__func__, QString("An unknown exception occurred"));
    }
    return false;
}
